package Module::CPANTS::Generator;
use strict;
use vars qw($VERSION);
$VERSION = "0.002";

# Errr, does nothing atm

1;

__END__

=head1 NAME

Module::CPANTS::Generator

=head1 DESCRIPTION

This module is part of the beta CPANTS project. It consists of many
modules that unpack CPAN, gather meta information about it and create
the Module::CPANTS distribution. You only need this if you want to add
more metrics to Module::CPANTS.

=head1 AUTHOR

Leon Brocard <acme@astray.com>

=head1 LICENSE

This code is distributed under the same license as Perl.

